@@ -16,7 +16,16 @@ from sklearn.cluster import KMeans
 from imutils.object_detection import non_max_suppression
 
 
-def load_east_model():
+def load_east_model() -> str:
+    """ # Load East model
+    This function load the frozen east model which is especialized on text detection.
+
+    Raises:
+        OSError: wrong directory path.
+
+    Returns:
+        str: model path.
+    """
     _path = list(
         filter(lambda _path: 'site-packages' in _path, sys.path))[-1]
     if _path:
@@ -34,7 +43,19 @@ def load_east_model():
     return model
 
 
-def get_model_from_s3(output):
+def get_model_from_s3(output: str) -> str:
+    """# Get model from S3
+    This function is used to download the frozen model from S3 when it isn't on the environment.
+
+    Args:
+        output (str): path to model location.
+
+    Raises:
+        ConnectionError: internet error.
+
+    Returns:
+        str: model path.
+    """
     url = 'https://drive.google.com/uc?export=download&id' + \
         '=1awJ8Vnwc7TKXQ6gMV1lyaL2qRKHbqnaI'
     try:
@@ -46,7 +67,18 @@ def get_model_from_s3(output):
         ) from error
 
 
-def get_input_type(_input):
+def get_input_type(_input) -> int:
+    """# Get input type
+
+    Args:
+        _input (Any): input image.
+
+    Raises:
+        TypeError: input out of pattern.
+
+    Returns:
+        int: input type describled by a number.
+    """
     if is_url(_input):
         input_type = 1
     elif is_path(_input):
@@ -59,7 +91,16 @@ def get_input_type(_input):
     return input_type
 
 
-def is_url(_input):
+def is_url(_input) -> bool:
+    """# Is url?
+    Try to understand if the input type is an url.
+
+    Args:
+        _input (Any): image input.
+
+    Returns:
+        bool: input is an url or not.
+    """
     if isinstance(_input, str):
         regex = re.compile(
             r'^(?:http|ftp)s?://'  # http:// or https://
@@ -76,7 +117,16 @@ def is_url(_input):
     return result
 
 
-def is_path(_input):
+def is_path(_input) -> bool:
+    """# Is path?
+    Try to understand if the input type is a path.
+
+    Args:
+        _input (Any): image input.
+
+    Returns:
+        boolean: input is a path or not.
+    """
     if isinstance(_input, str):
         file_path = path.realpath(_input)
         result = path.isfile(file_path)
@@ -86,7 +136,16 @@ def is_path(_input):
     return result
 
 
-def is_image(_input):
+def is_image(_input) -> bool:
+    """# Is image?
+    Try to understand if the input type is an image.
+
+    Args:
+        _input (Any): image input.
+
+    Returns:
+        boolean: input is a image or not.
+    """
     numpy_type = str(type(_input)) == \
         '<class '"'"'numpy.ndarray'"'"'>'
     plt_bmp_type = str(
@@ -117,19 +176,58 @@ def is_image(_input):
         plt_tiff_type
 
 
-def to_opencv_type(image):
+def to_opencv_type(image: Image) -> np.ndarray:
+    """ # To OpenCV type
+    Convert the image to OpenCV type.
+
+    Args:
+        image (Image): image to convert.
+
+    Returns:
+        np.ndarray: image converted.
+    """
     return np.asarray(image)[:, :, ::-1]
 
 
-def remove_alpha_channel(image):
+def remove_alpha_channel(image: np.ndarray) -> np.ndarray:
+    """ # Remove alpha channel
+    Remove the alpha channel from the image.
+
+    Args:
+        image (np.ndarray): image to remove alpha channel.
+
+    Returns:
+        np.ndarray: image without alpha channel.
+    """
     return image[:, :, :3]
 
 
-def brightness_contrast_optimization(image, alpha=1.5, beta=0):
+def brightness_contrast_optimization(image: np.ndarray, alpha=1.5, beta=0) -> np.ndarray:
+    """ # Brightness contrast optimization
+    Optimize the brightness and contrast of the image.
+
+    Args:
+        image (np.ndarray): image to optimize.
+        alpha (float, optional): brightness. Defaults to 1.5.
+        beta (int, optional): contrast. Defaults to 0.
+
+    Returns:
+        np.ndarray: image optimized.
+    """
     return cv2.convertScaleAbs(image, alpha=alpha, beta=beta)
 
 
-def run_kmeans(image, number_clusters):
+def run_kmeans(image: np.ndarray, number_clusters: int) -> dict:
+    """ # Run K-Means
+    Run the K-Means algorithm.
+
+    Args:
+        image (np.ndarray): image to run K-Means.
+        number_clusters (int): number of clusters.
+
+    Returns:
+        dict: colors.
+    """
     image = image.reshape((image.shape[0] * image.shape[1], 3))
     clusters = KMeans(n_clusters=number_clusters)
     clusters.fit(image)
@@ -138,7 +236,16 @@ def run_kmeans(image, number_clusters):
     return colors
 
 
-def centroid_histogram(clusters):
+def centroid_histogram(clusters: KMeans) -> np.ndarray:
+    """ # Centroid histogram
+    Calculate the centroid histogram.
+
+    Args:
+        clusters (KMeans): clusters to calculate the histogram.
+
+    Returns:
+        np.ndarray: histogram of the clusters.
+    """
     num_labels = np.arange(0, len(np.unique(clusters.labels_)) + 1)
     (histogram, _) = np.histogram(clusters.labels_, bins=num_labels)
     histogram = histogram.astype('float')
@@ -146,17 +253,39 @@ def centroid_histogram(clusters):
     return histogram
 
 
-def sort_colors(histogram, centroids):
+def sort_colors(histogram: np.ndarray, centroids: np.ndarray) -> list:
+    """ # Sort colors
+    Sort the colors by percentage of the image.
+
+    Args:
+        histogram (np.ndarray): histogram of the clusters.
+        centroids (np.ndarray): centroids of the clusters.
+
+    Returns:
+        list: sorted colors by percentage.
+    """
     sorted_colors = {}
     for (percentage, color) in zip(histogram, centroids):
         sorted_colors[tuple(color.astype('uint8').tolist())] = percentage
     return sorted(sorted_colors.items(), key=lambda x: x[1], reverse=True)
 
 
-def image_resize(image,
+def image_resize(image: np.ndarray,
                  width=None,
                  height=None,
                  inter=cv2.INTER_AREA):
+    """ # Image resize
+    Resize the image based on the width and height parameters.
+
+    Args:
+        image (np.ndarray): image to resize.
+        width (int, optional): width of the image. Defaults to None.
+        height (int, optional): height of the image. Defaults to None.
+        inter (int, optional): interpolation. Defaults to cv2.INTER_AREA.
+
+    Returns:
+        np.ndarray: image resized.
+    """
     dimensions = None
     (_height, _width) = image.shape[:2]
 
@@ -179,7 +308,17 @@ def image_resize(image,
     return resized
 
 
-def set_image_dpi(image, dpi):
+def set_image_dpi(image: np.ndarray, dpi: int) -> np.ndarray:
+    """ # Set image DPI
+    Set the DPI of the image based on the dpi parameter.
+
+    Args:
+        image (np.ndarray): image to set DPI.
+        dpi (int): DPI of the image.
+
+    Returns:
+        np.ndarray: image with DPI set.
+    """
     image = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
     image = Image.fromarray(image)
 
@@ -204,12 +343,24 @@ def open_close_filter(image, method, kernel=2):
     return image
 
 
-def unsharp_mask(image,
+def unsharp_mask(image: np.ndarray,
                  kernel_size=(5, 5),
                  sigma=1.0,
                  amount=1.0,
                  threshold=0):
-    """Return a sharpened version of the image, using an unsharp mask."""
+    """ # Unsharp mask
+    Return a sharpened version of the image, using an unsharp mask.
+
+    Args:
+        image (np.ndarray): image to sharpen.
+        kernel_size (tuple, optional): Gaussian kernel size. Defaults to (5, 5).
+        sigma (float, optional): Gaussian kernel standard deviation. Defaults to 1.0.
+        amount (float, optional): the strength of the sharpening. Defaults to 1.0.
+        threshold (int, optional): threshold for the low-contrast mask. Defaults to 0.
+
+    Returns:
+        np.ndarray: sharpened image.
+    """
     # https://homepages.inf.ed.ac.uk/rbf/HIPR2/unsharp.htm
     blurred = cv2.GaussianBlur(image, kernel_size, sigma)
     sharpened = float(amount + 1) * image - float(amount) * blurred
@@ -222,19 +373,47 @@ def unsharp_mask(image,
     return sharpened
 
 
-def dilate_image(image, kernel_size):
+def dilate_image(image: np.ndarray, kernel_size: int = 2) -> np.ndarray:
+    """ # Dilate image
+    Dilate the image based on the kernel size.
+
+    Args:
+        image (np.ndarray): image to dilate.
+        kernel_size (int, optional): kernel size. Defaults to 2.
+
+    Returns:
+        np.ndarray: dilated image.
+    """
     kernel = np.ones((kernel_size, kernel_size), np.uint8)
     return cv2.dilate(image, kernel, iterations=1)
 
 
-def binarize_image(image):
+def binarize_image(image: np.ndarray) -> np.ndarray:
+    """ # Binarize image
+    Binarize the image based on the OTSU method.
+
+    Args:
+        image (np.ndarray): image to binarize.
+
+    Returns:
+        np.ndarray: binarized image.
+    """
     image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
     bin_image = cv2.threshold(
         image, 0, 255, cv2.THRESH_BINARY+cv2.THRESH_OTSU)[1]
     return bin_image
 
 
-def east_process(image):
+def east_process(image: np.ndarray) -> list:
+    """ # EAST process
+    Process the image using the EAST model, and return the boxes.
+
+    Args:
+        image (np.ndarray): image to process.
+
+    Returns:
+        list: list of boxes found.
+    """
     _image = image.copy()
     (_height, _width) = get_size(image)
     (ratio_height, ratio_width) = get_ratio(_height, _width)
@@ -254,15 +433,46 @@ def east_process(image):
     return sort_boxes(results)
 
 
-def get_size(image):
+def get_size(image: np.ndarray) -> tuple:
+    """ # Get size of image
+    Get the size of the image (height, width).
+
+    Args:
+        image (np.ndarray): image to get the size.
+
+    Returns:
+        tuple: (height, width).
+    """
     return image.shape[0], image.shape[1]
 
 
-def get_ratio(height, width):
+def get_ratio(height: int, width: int) -> tuple:
+    """ # Get ratio of image
+    Get the ratio of the image (height, width).
+
+    Args:
+        height (int): height of the image.
+        width (int): width of the image.
+
+    Returns:
+        tuple: (height, width).
+    """
     return height / float(640), width / float(640)
 
 
-def run_east(net, image, height, width):
+def run_east(net: cv2.dnn_Net, image: np.ndarray, height: int, width: int) -> tuple:
+    """ # Run EAST
+    Run the EAST model and return the scores and geometry.
+
+    Args:
+        net (cv2.dnn_Net): EAST model.
+        image (np.ndarray): image to process.
+        height (int): height of the image.
+        width (int): width of the image.
+
+    Returns:
+        tuple: (scores, geometry).
+    """
     layer_names = [
         'feature_fusion/Conv_7/Sigmoid',
         'feature_fusion/concat_3'
@@ -276,7 +486,18 @@ def run_east(net, image, height, width):
     return scores, geometry
 
 
-def decode_predictions(scores, geometry, min_confidence):
+def decode_predictions(scores: np.ndarray, geometry: np.ndarray, min_confidence: float) -> tuple:
+    """ # Decode predictions from EAST
+    Decode the predictions from the EAST model and return the boxes and confidences.
+
+    Args:
+        scores (np.ndarray): scores from the EAST model.
+        geometry (np.ndarray): geometry from the EAST model.
+        min_confidence (float): minimum confidence to consider.
+
+    Returns:
+        tuple: (rects, confidences).
+    """
     (num_rows, num_cols) = scores.shape[2:4]
     rects = []
     confidences = []
@@ -324,13 +545,28 @@ def decode_predictions(scores, geometry, min_confidence):
 
 
 def apply_boxes(
-        boxes,
-        image,
-        ratio_height,
-        ratio_width,
-        height,
-        width,
-        padding):
+        boxes: list,
+        image: np.ndarray,
+        ratio_height: float,
+        ratio_width: float,
+        height: int,
+        width: int,
+        padding: float) -> tuple:
+    """ # Apply boxes to image
+    Apply the boxes to the image and return the results and the image.
+
+    Args:
+        boxes (list): boxes to apply.
+        image (np.ndarray): image to apply the boxes.
+        ratio_height (float): ratio of the height.
+        ratio_width (float): ratio of the width.
+        height (int): height of the image.
+        width (int): width of the image.
+        padding (float): padding to apply.
+
+    Returns:
+        tuple: (results, image) where results is a list of tuples (text, box) and image is the image with the boxes.
+    """
     results = []
     for (start_x, start_y, end_x, end_y) in boxes:
         start_x = int(start_x * ratio_width)
@@ -357,7 +593,16 @@ def apply_boxes(
     return results, image
 
 
-def sort_boxes(boxes):
+def sort_boxes(boxes: list) -> list:
+    """ # Sort boxes
+    Sort the boxes and return the sorted boxes in a list.
+
+    Args:
+        boxes (list): boxes to sort.
+
+    Returns:
+        list: sorted boxes.
+    """
     sorted_text = []
     lines_values = sorted(list(set(map(lambda box: box[0][1], boxes))))
     for value in lines_values:
@@ -372,7 +617,16 @@ def sort_boxes(boxes):
     return flatten_sorted_text
 
 
-def get_image_from_url(url):
+def get_image_from_url(url: str) -> np.ndarray:
+    """ # Get image from url
+    Get the image from the url and return the image.
+
+    Args:
+        url (str): url to get the image.
+
+    Returns:
+        np.ndarray: image.
+    """
     try:
         response = requests.get(url)
     except Exception as error:
@@ -383,13 +637,28 @@ def get_image_from_url(url):
     return response
 
 
-def load_dict_to_memory():
+def load_dict_to_memory() -> SymSpell:
+    """ # Load dictionary to memory
+    Load the dictionary to memory and return the SymSpell object.
+
+    Returns:
+        SymSpell: SymSpell object with the dictionary loaded.
+    """
     sym_spell = SymSpell(max_dictionary_edit_distance=2, prefix_length=7)
     sym_spell.load_pickle('./src/dictionary/dictionary.pkl')
     return sym_spell
 
 
-def get_word_suggestion(symspell, input_term):
+def get_word_suggestion(symspell: SymSpell, input_term: str) -> str:
+    """ # Get word suggestion
+    Get the word suggestion from the input term and return the suggestion if it exists.
+
+    Args:
+        symspell (SymSpell): SymSpell object with the dictionary loaded.
+
+    Returns:
+        str: suggestion if it exists.
+    """
     get_digits = re.findall(r'\d+', input_term)
 
     if len(get_digits) == 0:
